@@ -3,6 +3,7 @@ from typing import Generator, Any, Optional
 from fastapi import FastAPI, Request
 from fastapi import Depends, HTTPException
 from fastapi.staticfiles import StaticFiles
+from fastapi.templating import Jinja2Templates
 
 from starlette.middleware.cors import CORSMiddleware
 
@@ -10,7 +11,17 @@ from sqlalchemy.orm import Session
 
 from abing.routes.v1.api import api_router
 from abing.core.config import settings
-from fastapi.templating import Jinja2Templates
+from abing.core.exceptions import SentryNotFoundException
+
+try:
+    import sentry_sdk
+    from sentry_sdk.integrations.asgi import SentryAsgiMiddleware
+except (ModuleNotFoundError, ImportError):
+    if settings.SENTRY_DSN is not None:
+        # NOTE: future should change custom exception.
+        raise SentryNotFoundException(
+            "For using sentry, please install sentry sdk(simply you could install via pip install abing[sentry])."
+        )
 
 app = FastAPI(title=settings.PROJECT_NAME)
 
@@ -34,3 +45,11 @@ app.add_middleware(
     allow_methods=["*"],
     allow_headers=["*"],
 )
+
+# NOTE: Sentry configuration should place in last.
+if settings.SENTRY_DSN:
+    sentry_sdk.init(
+        dsn=settings.SENTRY_DSN,
+        traces_sample_rate=1.0,
+    )
+    app = SentryAsgiMiddleware(app)
