@@ -9,6 +9,7 @@ from abing.db.base_class import Base
 if TYPE_CHECKING:
     from .experiment import Experiment  # noqa: F401
     from .feature import Feature  # noqa: F401
+    from .allocation import Allocation
 
 
 class Arm(Base):
@@ -22,6 +23,7 @@ class Arm(Base):
     experiment_id = Column(Integer, ForeignKey("experiments.id"), nullable=False)
     experiment = relationship("Experiment", back_populates="arms")
     features = relationship("Feature", back_populates="arm", cascade="all,delete")
+    allocations = relationship("Allocation", back_populates="arm", cascade="all,delete")
     time_created = Column(DateTime(timezone=True), server_default=func.now())
     time_updated = Column(
         DateTime(timezone=True), server_default=func.now(), onupdate=func.now()
