@@ -1,5 +1,5 @@
 from typing import List, Optional
-from datetime import datetime
+from datetime import datetime, date
 from pydantic import BaseModel
 from .arm import Arm
 
@@ -8,8 +8,8 @@ class ExperimentBase(BaseModel):
     name: str
     description: Optional[str] = None
     is_running: Optional[bool] = False
-    start_date: Optional[datetime]
-    end_date: Optional[datetime]
+    start_date: Optional[date]
+    end_date: Optional[date]
 
 
 class ExperimentCreate(ExperimentBase):
@@ -20,8 +20,8 @@ class ExperimentUpdate(ExperimentBase):
     name: Optional[str]
     description: Optional[str]
     is_running: Optional[bool]
-    start_date: Optional[datetime]
-    end_date: Optional[datetime]
+    start_date: Optional[date]
+    end_date: Optional[date]
 
 
 class ExperimentInDBBase(ExperimentBase):
